@@ -6,6 +6,8 @@ use Test::Builder;
 use Exporter qw(import);
 use Gnuplot::Builder::Process;
 
+$Gnuplot::Builder::Process::ASYNC = 0;
+
 our @EXPORT_OK = qw(if_no_file check_process_finish cond_check);
 
 sub if_no_file {
@@ -21,7 +23,7 @@ sub if_no_file {
 
 sub check_process_finish {
     note("wait for all managed sub-processes to finish");
-    Gnuplot::Builder::Process::FOR_TEST_wait_all();
+    Gnuplot::Builder::Process->wait_all();
     note("Gnuplot::Builder params:");
     note("  COMMAND: " . (join " ", @Gnuplot::Builder::Process::COMMAND));
     note("  PAUSE_FINISH: $Gnuplot::Builder::Process::PAUSE_FINISH");
